@@ -57,8 +57,6 @@ enum
 
 static guint egg_editable_toolbar_signals[LAST_SIGNAL] = { 0 };
 
-#define EGG_EDITABLE_TOOLBAR_GET_PRIVATE(object)(G_TYPE_INSTANCE_GET_PRIVATE ((object), EGG_TYPE_EDITABLE_TOOLBAR, EggEditableToolbarPrivate))
-
 struct _EggEditableToolbarPrivate
 {
   GtkUIManager *manager;
@@ -81,7 +79,7 @@ struct _EggEditableToolbarPrivate
   GtkToolItem *dnd_toolitem;
 };
 
-G_DEFINE_TYPE (EggEditableToolbar, egg_editable_toolbar, GTK_TYPE_BOX)
+G_DEFINE_TYPE_WITH_PRIVATE (EggEditableToolbar, egg_editable_toolbar, GTK_TYPE_BOX)
 
 static int
 get_dock_position (EggEditableToolbar *etoolbar,
@@ -161,11 +159,13 @@ find_action (EggEditableToolbar *etoolbar,
 
   for (; l != NULL; l = l->next)
     {
+      G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
       GtkAction *tmp;
 
       tmp = gtk_action_group_get_action (GTK_ACTION_GROUP (l->data), name);
       if (tmp)
-	action = tmp;
+        action = tmp;
+      G_GNUC_END_IGNORE_DEPRECATIONS;
     }
 
   return action;
@@ -196,22 +196,27 @@ drag_begin_cb (GtkWidget          *widget,
 	       EggEditableToolbar *etoolbar)
 {
   GtkAction *action;
+  const gchar *action_name;
   gint flags;
 
   gtk_widget_hide (widget);
 
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
   action = gtk_activatable_get_related_action (GTK_ACTIVATABLE (widget));
 
   if (action == NULL) return;
 
+  action_name = gtk_action_get_name (action);
+  G_GNUC_END_IGNORE_DEPRECATIONS;
+
   flags = egg_toolbars_model_get_name_flags (etoolbar->priv->model,
-					     gtk_action_get_name (action));
+                                             action_name);
   if (!(flags & EGG_TB_MODEL_NAME_INFINITE))
     {
       flags &= ~EGG_TB_MODEL_NAME_USED;
       egg_toolbars_model_set_name_flags (etoolbar->priv->model,
-					 gtk_action_get_name (action),
-					 flags);
+                                         action_name,
+                                         flags);
     }
 }
 
@@ -221,25 +226,30 @@ drag_end_cb (GtkWidget          *widget,
 	     EggEditableToolbar *etoolbar)
 {
   GtkAction *action;
+  const gchar *action_name;
   gint flags;
 
   if (gtk_widget_get_parent (widget) != NULL)
     {
       gtk_widget_show (widget);
 
+      G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
       action = gtk_activatable_get_related_action (GTK_ACTIVATABLE (widget));
 
       if (action == NULL) return;
 
+      action_name = gtk_action_get_name (action);
+      G_GNUC_END_IGNORE_DEPRECATIONS;
+
       flags = egg_toolbars_model_get_name_flags (etoolbar->priv->model,
-						 gtk_action_get_name (action));
+                                                 action_name);
       if (!(flags & EGG_TB_MODEL_NAME_INFINITE))
         {
-	  flags |= EGG_TB_MODEL_NAME_USED;
-	  egg_toolbars_model_set_name_flags (etoolbar->priv->model,
-					     gtk_action_get_name (action),
-					     flags);
-	}
+          flags |= EGG_TB_MODEL_NAME_USED;
+          egg_toolbars_model_set_name_flags (etoolbar->priv->model,
+                                             action_name,
+                                             flags);
+        }
     }
 }
 
@@ -504,7 +514,9 @@ configure_item_tooltip (GtkToolItem *item)
 {
   GtkAction *action;
 
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
   action = gtk_activatable_get_related_action (GTK_ACTIVATABLE (item));
+  G_GNUC_END_IGNORE_DEPRECATIONS;
 
   if (action != NULL)
     {
@@ -583,6 +595,7 @@ create_item_from_action (EggEditableToolbar *etoolbar,
       GtkAction *action = find_action (etoolbar, name);
       if (action == NULL) return NULL;
 
+      G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
       item = GTK_TOOL_ITEM (gtk_action_create_tool_item (action));
 
       /* Normally done on-demand by the GtkUIManager, but no
@@ -590,6 +603,7 @@ create_item_from_action (EggEditableToolbar *etoolbar,
        */
       gtk_action_set_accel_group
         (action, gtk_ui_manager_get_accel_group(etoolbar->priv->manager));
+      G_GNUC_END_IGNORE_DEPRECATIONS;
 
       g_signal_connect_object (action, "notify::sensitive",
                                G_CALLBACK (action_sensitive_cb), item, 0);
@@ -803,7 +817,9 @@ toggled_visibility_cb (GtkToggleAction *action,
   gboolean visible;
   gint i;
 
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
   visible = gtk_toggle_action_get_active (action);
+  G_GNUC_END_IGNORE_DEPRECATIONS;
   for (i = 0; i < priv->visibility_actions->len; i++)
     if (g_ptr_array_index (priv->visibility_actions, i) == action)
       break;
@@ -934,24 +950,30 @@ toolbar_visibility_refresh (EggEditableToolbar *etoolbar)
 
       if (i >= priv->visibility_actions->len)
         {
-	  action = gtk_toggle_action_new (action_name, action_label, NULL, NULL);
-	  g_ptr_array_add (priv->visibility_actions, action);
-	  g_signal_connect_object (action, "toggled",
-				   G_CALLBACK (toggled_visibility_cb),
-				   etoolbar, 0);
-	  gtk_action_group_add_action (priv->actions, GTK_ACTION (action));
-	}
+          G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
+          action = gtk_toggle_action_new (action_name, action_label, NULL, NULL);
+          G_GNUC_END_IGNORE_DEPRECATIONS;
+          g_ptr_array_add (priv->visibility_actions, action);
+          g_signal_connect_object (action, "toggled",
+                                   G_CALLBACK (toggled_visibility_cb),
+                                   etoolbar, 0);
+          G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
+          gtk_action_group_add_action (priv->actions, GTK_ACTION (action));
+          G_GNUC_END_IGNORE_DEPRECATIONS;          
+        }
       else
         {
 	  action = g_ptr_array_index (priv->visibility_actions, i);
 	  g_object_set (action, "label", action_label, NULL);
         }
 
+      G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
       gtk_action_set_visible (GTK_ACTION (action), (egg_toolbars_model_get_flags (priv->model, i)
-						    & EGG_TB_MODEL_NOT_REMOVABLE) == 0);
+                                                    & EGG_TB_MODEL_NOT_REMOVABLE) == 0);
       gtk_action_set_sensitive (GTK_ACTION (action), showing);
       gtk_toggle_action_set_active (action, gtk_widget_get_visible
-				    (get_dock_nth (etoolbar, i)));
+                                    (get_dock_nth (etoolbar, i)));
+      G_GNUC_END_IGNORE_DEPRECATIONS;
 
       for (list = priv->visibility_paths; list != NULL; list = g_list_next (list))
         {
@@ -969,7 +991,9 @@ toolbar_visibility_refresh (EggEditableToolbar *etoolbar)
     {
       action = g_ptr_array_index (priv->visibility_actions, i);
       g_ptr_array_remove_index_fast (priv->visibility_actions, i);
+      G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
       gtk_action_group_remove_action (priv->actions, GTK_ACTION (action));
+      G_GNUC_END_IGNORE_DEPRECATIONS;
       i++;
     }
 }
@@ -1334,7 +1358,7 @@ egg_editable_toolbar_init (EggEditableToolbar *etoolbar)
 
   EggEditableToolbarPrivate *priv;
 
-  priv = etoolbar->priv = EGG_EDITABLE_TOOLBAR_GET_PRIVATE (etoolbar);
+  priv = etoolbar->priv = egg_editable_toolbar_get_instance_private (etoolbar);
 
   priv->save_hidden = TRUE;
 
@@ -1403,10 +1427,12 @@ egg_editable_toolbar_set_ui_manager (EggEditableToolbar *etoolbar,
 
   etoolbar->priv->manager = g_object_ref (manager);
 
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
   etoolbar->priv->actions = gtk_action_group_new ("ToolbarActions");
   gtk_action_group_set_translation_domain (etoolbar->priv->actions, GETTEXT_PACKAGE);
   gtk_action_group_add_actions (etoolbar->priv->actions, actions,
 		 		G_N_ELEMENTS (actions), etoolbar);
+  G_GNUC_END_IGNORE_DEPRECATIONS;
   gtk_ui_manager_insert_action_group (manager, etoolbar->priv->actions, -1);
   g_object_unref (etoolbar->priv->actions);
 
@@ -1440,9 +1466,11 @@ egg_editable_toolbar_set_selected (EggEditableToolbar *etoolbar,
       editable = FALSE;
     }
 
+  G_GNUC_BEGIN_IGNORE_DEPRECATIONS;
   gtk_action_set_visible (find_action (etoolbar, "RemoveToolbar"), (toolbar != NULL) && (etoolbar->priv->edit_mode > 0));
   gtk_action_set_visible (find_action (etoolbar, "RemoveToolItem"), (toolitem != NULL) && editable);
   gtk_action_set_visible (find_action (etoolbar, "MoveToolItem"), (toolitem != NULL) && editable);
+  G_GNUC_END_IGNORE_DEPRECATIONS;
 }
 
 static void
@@ -1606,8 +1634,6 @@ egg_editable_toolbar_class_init (EggEditableToolbarClass *klass)
 							 "Edit Mode",
 							 FALSE,
 							 G_PARAM_READWRITE | G_PARAM_STATIC_NAME | G_PARAM_STATIC_NICK | G_PARAM_STATIC_BLURB));
-
-  g_type_class_add_private (object_class, sizeof (EggEditableToolbarPrivate));
 }
 
 GtkWidget *
