@@ -420,8 +420,6 @@ filter_files (GSList *files, GList **file_list, GList **error_list)
 						      g_file_get_uri (file));
 			break;
 		}
-
-		g_object_unref (file);
 	}
 
 	*file_list  = g_list_reverse (*file_list);
@@ -489,7 +487,7 @@ eom_job_transform_class_init (EomJobTransformClass *class)
 /**
  * eom_job_transform_new:
  * @images: (element-type EomImage) (transfer full): a #EomImage list
- * @trans: a #EogTransform
+ * @trans: a #EomTransform
  *
  * Create a new #EomJob for image transformation.
  *
