@@ -103,11 +103,11 @@ main (int argc, char **argv)
 	bind_textdomain_codeset (GETTEXT_PACKAGE, "UTF-8");
 	textdomain (GETTEXT_PACKAGE);
 
-	gdk_set_allowed_backends ("x11");
+	gdk_set_allowed_backends ("wayland,x11");
 
 	ctx = g_option_context_new (_("[FILE…]"));
 	g_option_context_add_main_entries (ctx, goption_options, PACKAGE);
-	/* Option groups are free'd together with the context 
+	/* Option groups are free'd together with the context
 	 * Using gtk_get_option_group here initializes gtk during parsing */
 	g_option_context_add_group (ctx, gtk_get_option_group (TRUE));
 #ifdef HAVE_INTROSPECTION
